==> haskell-skylighting-format-context-0.1.0.2-82-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-2pcAnzEWLwNBEM1RBqLQrD
key:                  skylighting-format-context-0.1.0.2-2pcAnzEWLwNBEM1RBqLQrD
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  294f8a45cf5a05461cb8f127b6684715
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-2pcAnzEWLwNBEM1RBqLQrD
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14-G627Fh4sueu1RyTRIOQ6ye text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-86-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-FLVjN31mxiwFHrr7nP4Bzl
key:                  skylighting-format-context-0.1.0.2-FLVjN31mxiwFHrr7nP4Bzl
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  e5725561d1442fe4624525692696bc7c
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-FLVjN31mxiwFHrr7nP4Bzl
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14-HIoOlDdQH0BHPsU34YJXam text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
